@@ -8,13 +8,14 @@ A binary sensor can be:
 
 A BinarySensor may also have Actions attached which are executed after state was changed.
 """
+from __future__ import annotations
+
 import asyncio
 import time
-from typing import TYPE_CHECKING, Any, Dict, Iterator, List, Optional, cast
+from typing import TYPE_CHECKING, Any, Iterator, cast
 
 from xknx.remote_value import GroupAddressesType, RemoteValueSwitch
 
-from .action import Action
 from .device import Device, DeviceCallbackType
 
 if TYPE_CHECKING:
@@ -25,41 +26,35 @@ if TYPE_CHECKING:
 class BinarySensor(Device):
     """Class for binary sensor."""
 
-    # pylint: disable=too-many-instance-attributes
     def __init__(
         self,
-        xknx: "XKNX",
+        xknx: XKNX,
         name: str,
         group_address_state: GroupAddressesType = None,
         invert: bool = False,
         sync_state: bool = True,
         ignore_internal_state: bool = False,
-        device_class: Optional[str] = None,
-        reset_after: Optional[float] = None,
-        actions: Optional[List[Action]] = None,
-        context_timeout: Optional[float] = None,
+        device_class: str | None = None,
+        reset_after: float | None = None,
+        context_timeout: float | None = None,
         ha_value_template: Any = None,
-        device_updated_cb: Optional[DeviceCallbackType] = None,
+        device_updated_cb: DeviceCallbackType | None = None,
     ):
         """Initialize BinarySensor class."""
-        # pylint: disable=too-many-arguments
         super().__init__(xknx, name, device_updated_cb)
-        if actions is None:
-            actions = []
 
-        self.actions = actions
         self.device_class = device_class
         self.ha_value_template = ha_value_template
         self.ignore_internal_state = ignore_internal_state or bool(context_timeout)
         self.reset_after = reset_after
-        self.state: Optional[bool] = None
+        self.state: bool | None = None
 
         self._context_timeout = context_timeout
         self._count_set_on = 0
         self._count_set_off = 0
-        self._last_set: Optional[float] = None
-        self._reset_task: Optional[asyncio.Task[None]] = None
-        self._context_task: Optional[asyncio.Task[None]] = None
+        self._last_set: float | None = None
+        self._reset_task: asyncio.Task[None] | None = None
+        self._context_task: asyncio.Task[None] | None = None
         # TODO: log a warning if reset_after and sync_state are true ? This could cause actions to self-fire.
         self.remote_value = RemoteValueSwitch(
             xknx,
@@ -76,10 +71,15 @@ class BinarySensor(Device):
         yield self.remote_value
 
     @property
-    def unique_id(self) -> Optional[str]:
+    def unique_id(self) -> str | None:
         """Return unique id for this device."""
         return f"{self.remote_value.group_address_state}"
 
+    @property
+    def last_telegram(self) -> Telegram | None:
+        """Return the last telegram received from the RemoteValue."""
+        return self.remote_value.telegram
+
     def __del__(self) -> None:
         """Destructor. Cleaning up if this was not done before."""
         try:
@@ -91,37 +91,6 @@ class BinarySensor(Device):
             pass
         super().__del__()
 
-    @classmethod
-    def from_config(
-        cls, xknx: "XKNX", name: str, config: Dict[str, Any]
-    ) -> "BinarySensor":
-        """Initialize object from configuration structure."""
-        group_address_state = config.get("group_address_state")
-        invert = config.get("invert", False)
-        context_timeout = config.get("context_timeout")
-        reset_after = config.get("reset_after")
-        sync_state = config.get("sync_state", True)
-        device_class = config.get("device_class")
-        ignore_internal_state = config.get("ignore_internal_state", False)
-        actions = []
-        if "actions" in config:
-            for action in config["actions"]:
-                action = Action.from_config(xknx, action)
-                actions.append(action)
-
-        return cls(
-            xknx,
-            name,
-            group_address_state=group_address_state,
-            invert=invert,
-            sync_state=sync_state,
-            ignore_internal_state=ignore_internal_state,
-            context_timeout=context_timeout,
-            reset_after=reset_after,
-            device_class=device_class,
-            actions=actions,
-        )
-
     async def _state_from_remote_value(self) -> None:
         """Update the internal state from RemoteValue (Callback)."""
         if self.remote_value.value is not None:
@@ -153,15 +122,11 @@ class BinarySensor(Device):
         await self.after_update()
 
     async def _trigger_callbacks(self) -> None:
-        """Trigger callbacks for device and execute actions if any."""
+        """Trigger callbacks for device if any."""
         await self.after_update()
 
-        for action in self.actions:
-            if action.test_if_applicable(cast(bool, self.state), self.counter):
-                await action.execute()
-
     @property
-    def counter(self) -> Optional[int]:
+    def counter(self) -> int | None:
         """Return current counter for sensor."""
         if self._context_timeout:
             return self._count_set_on if self.state else self._count_set_off
@@ -226,6 +191,6 @@ class BinarySensor(Device):
 
     def __str__(self) -> str:
         """Return object as readable string."""
-        return '<BinarySensor name="{}" remote_value="{}" state="{}"/>'.format(
-            self.name, self.remote_value.group_addr_str(), self.state
+        return '<BinarySensor name="{}" remote_value={} state={} />'.format(
+            self.name, self.remote_value.group_addr_str(), self.state.__repr__()
         )
