@@ -11,7 +11,9 @@ read from an internet service (e.g. Yahoo weather) and exposed to
 ths KNX bus. KNX sensors may show this outside temperature within their
 LCD display.
 """
-from typing import TYPE_CHECKING, Any, Dict, Iterator, Optional, Union
+from __future__ import annotations
+
+from typing import TYPE_CHECKING, Any, Iterator
 
 from xknx.remote_value import (
     GroupAddressesType,
@@ -32,17 +34,16 @@ class ExposeSensor(Device):
 
     def __init__(
         self,
-        xknx: "XKNX",
+        xknx: XKNX,
         name: str,
-        group_address: Optional[GroupAddressesType] = None,
-        value_type: Optional[Union[int, str]] = None,
-        device_updated_cb: Optional[DeviceCallbackType] = None,
+        group_address: GroupAddressesType | None = None,
+        value_type: int | str | None = None,
+        device_updated_cb: DeviceCallbackType | None = None,
     ):
         """Initialize Sensor class."""
-        # pylint: disable=too-many-arguments
         super().__init__(xknx, name, device_updated_cb)
 
-        self.sensor_value: Union[RemoteValueSensor, RemoteValueSwitch]
+        self.sensor_value: RemoteValueSensor | RemoteValueSwitch
         if value_type == "binary":
             self.sensor_value = RemoteValueSwitch(
                 xknx,
@@ -65,16 +66,6 @@ class ExposeSensor(Device):
         """Iterate the devices RemoteValue classes."""
         yield self.sensor_value
 
-    @classmethod
-    def from_config(
-        cls, xknx: "XKNX", name: str, config: Dict[str, Any]
-    ) -> "ExposeSensor":
-        """Initialize object from configuration structure."""
-        group_address = config.get("group_address")
-        value_type = config.get("value_type")
-
-        return cls(xknx, name, group_address=group_address, value_type=value_type)
-
     async def process_group_write(self, telegram: "Telegram") -> None:
         """Process incoming and outgoing GROUP WRITE telegram."""
         await self.sensor_value.process(telegram)
@@ -87,7 +78,7 @@ class ExposeSensor(Device):
         """Set new value."""
         await self.sensor_value.set(value)
 
-    def unit_of_measurement(self) -> Optional[str]:
+    def unit_of_measurement(self) -> str | None:
         """Return the unit of measurement."""
         return self.sensor_value.unit_of_measurement
 
@@ -97,9 +88,9 @@ class ExposeSensor(Device):
 
     def __str__(self) -> str:
         """Return object as readable string."""
-        return '<ExposeSensor name="{}" ' 'sensor="{}" value="{}" unit="{}"/>'.format(
+        return '<ExposeSensor name="{}" sensor={} value={} unit="{}"/>'.format(
             self.name,
             self.sensor_value.group_addr_str(),
-            self.resolve_state(),
+            self.resolve_state().__repr__(),
             self.unit_of_measurement(),
         )
