@@ -3,8 +3,11 @@ Implementation of KNX 4 byte Float-values.
 
 They correspond to the the following KDN DPT 14 class.
 """
+from __future__ import annotations
+
+from math import ceil, log10
 import struct
-from typing import Optional, Tuple
+from typing import cast
 
 from xknx.exceptions import ConversionError
 
@@ -24,22 +27,30 @@ class DPT4ByteFloat(DPTBase):
     """
 
     dpt_main_number = 14
-    dpt_sub_number: Optional[int] = None
+    dpt_sub_number: int | None = None
     value_type = "4byte_float"
     unit = ""
     payload_length = 4
 
     @classmethod
-    def from_knx(cls, raw: Tuple[int, ...]) -> float:
+    def from_knx(cls, raw: tuple[int, ...]) -> float:
         """Parse/deserialize from KNX/IP raw data (big endian)."""
         cls.test_bytesarray(raw)
         try:
-            return struct.unpack(">f", bytes(raw))[0]  # type: ignore
+            raw_float = cast(float, struct.unpack(">f", bytes(raw))[0])
         except struct.error:
             raise ConversionError("Could not parse %s" % cls.__name__, raw=raw)
+        try:
+            # round to 7 digit precicion independent of exponent - same value as ETS 5.7 group monitor
+            return round(raw_float, 7 - ceil(log10(abs(raw_float))))
+        except (ValueError, OverflowError):
+            # account for 0 and special values
+            # ValueError: log10(0.0); ceil(float('nan'))
+            # OverflowError: ceil(float('inf'))
+            return raw_float
 
     @classmethod
-    def to_knx(cls, value: float) -> Tuple[int, ...]:
+    def to_knx(cls, value: float) -> tuple[int, ...]:
         """Serialize to KNX/IP raw data."""
         try:
             knx_value = float(value)
