@@ -6,6 +6,8 @@ Remote value can be :
 - a group address for reading a KNX value,
 - or a group of both representing the same value.
 """
+from __future__ import annotations
+
 from abc import ABC, abstractmethod
 import logging
 from typing import (
@@ -16,7 +18,6 @@ from typing import (
     Generic,
     Iterator,
     List,
-    Optional,
     TypeVar,
     Union,
 )
@@ -24,47 +25,50 @@ from typing import (
 from xknx.dpt.dpt import DPTArray, DPTBinary, DPTPayloadType
 from xknx.exceptions import CouldNotParseTelegram
 from xknx.telegram import GroupAddress, Telegram
+from xknx.telegram.address import (
+    DeviceGroupAddress,
+    InternalGroupAddress,
+    parse_device_group_address,
+)
 from xknx.telegram.apci import GroupValueResponse, GroupValueWrite
 
 if TYPE_CHECKING:
-    from xknx.telegram.address import GroupAddressableType
+    from xknx.telegram.address import DeviceAddressableType
     from xknx.xknx import XKNX
 
 logger = logging.getLogger("xknx.log")
 
 AsyncCallbackType = Callable[[], Awaitable[None]]
-GroupAddressesType = Union["GroupAddressableType", List["GroupAddressableType"]]
+GroupAddressesType = Union["DeviceAddressableType", List["DeviceAddressableType"]]
 ValueType = TypeVar("ValueType")
 
 
 class RemoteValue(ABC, Generic[DPTPayloadType, ValueType]):
     """Class for managing remote knx value."""
 
-    # pylint: disable=too-many-instance-attributes
     def __init__(
         self,
-        xknx: "XKNX",
-        group_address: Optional[GroupAddressesType] = None,
-        group_address_state: Optional[GroupAddressesType] = None,
+        xknx: XKNX,
+        group_address: GroupAddressesType | None = None,
+        group_address_state: GroupAddressesType | None = None,
         sync_state: bool = True,
-        device_name: Optional[str] = None,
-        feature_name: Optional[str] = None,
-        after_update_cb: Optional[AsyncCallbackType] = None,
+        device_name: str | None = None,
+        feature_name: str | None = None,
+        after_update_cb: AsyncCallbackType | None = None,
     ):
         """Initialize RemoteValue class."""
-        # pylint: disable=too-many-arguments
-        self.xknx: "XKNX" = xknx
-        self.passive_group_addresses: List[GroupAddress] = []
+        self.xknx: XKNX = xknx
+        self.passive_group_addresses: list[DeviceGroupAddress] = []
 
         def unpack_group_addresses(
-            addresses: Optional[GroupAddressesType],
-        ) -> Optional[GroupAddress]:
+            addresses: GroupAddressesType | None,
+        ) -> DeviceGroupAddress | None:
             """Parse group addresses and assign passive addresses when given."""
             if addresses is None:
                 return None
             if not isinstance(addresses, list):
-                return GroupAddress(addresses)
-            active, *passive = map(GroupAddress, addresses)
+                return parse_device_group_address(addresses)
+            active, *passive = map(parse_device_group_address, addresses)
             self.passive_group_addresses.extend(passive)  # type: ignore
             return active
 
@@ -73,8 +77,9 @@ class RemoteValue(ABC, Generic[DPTPayloadType, ValueType]):
 
         self.device_name: str = "Unknown" if device_name is None else device_name
         self.feature_name: str = "Unknown" if feature_name is None else feature_name
-        self.after_update_cb: Optional[AsyncCallbackType] = after_update_cb
-        self.payload: Optional[DPTPayloadType] = None
+        self._value: ValueType | None = None
+        self.telegram: Telegram | None = None
+        self.after_update_cb: AsyncCallbackType | None = after_update_cb
 
         if sync_state and self.group_address_state:
             self.xknx.state_updater.register_remote_value(
@@ -90,6 +95,25 @@ class RemoteValue(ABC, Generic[DPTPayloadType, ValueType]):
             # AttributeError if instantiation failed (tests mostly)
             pass
 
+    @property
+    def value(self) -> ValueType | None:
+        """Get current value."""
+        return self._value
+
+    @value.setter
+    def value(self, value: Any) -> None:
+        """Set new value without creating a Telegram or calling after_update_cb. Raises ConversionError on invalid value."""
+        if value is not None:
+            # raises ConversionError on invalid value
+            self.to_knx(value)
+        self._value = value
+
+    async def update_value(self, value: Any) -> None:
+        """Set new value without creating a Telegram. Awaits after_update_cb. Raises ConversionError on invalid value."""
+        self.value = value
+        if self.after_update_cb is not None:
+            await self.after_update_cb()
+
     @property
     def initialized(self) -> bool:
         """Evaluate if remote value is initialized with group address."""
@@ -109,22 +133,22 @@ class RemoteValue(ABC, Generic[DPTPayloadType, ValueType]):
         """Evaluate if remote value has a group_address set."""
         return bool(self.group_address)
 
-    def has_group_address(self, group_address: GroupAddress) -> bool:
+    def has_group_address(self, group_address: DeviceGroupAddress) -> bool:
         """Test if device has given group address."""
 
-        def _internal_addresses() -> Iterator[Optional[GroupAddress]]:
+        def remote_value_addresses() -> Iterator[DeviceGroupAddress | None]:
             """Yield all group_addresses."""
             yield self.group_address
             yield self.group_address_state
             yield from self.passive_group_addresses
 
-        return group_address in _internal_addresses()
+        return group_address in remote_value_addresses()
 
     @abstractmethod
     # TODO: typing - remove Optional
     def payload_valid(
-        self, payload: Optional[Union[DPTArray, DPTBinary]]
-    ) -> Optional[DPTPayloadType]:
+        self, payload: DPTArray | DPTBinary | None
+    ) -> DPTPayloadType | None:
         """Return payload if telegram payload may be parsed - to be implemented in derived class."""
 
     @abstractmethod
@@ -138,7 +162,7 @@ class RemoteValue(ABC, Generic[DPTPayloadType, ValueType]):
     async def process(self, telegram: Telegram, always_callback: bool = False) -> bool:
         """Process incoming or outgoing telegram."""
         if not isinstance(
-            telegram.destination_address, GroupAddress
+            telegram.destination_address, (GroupAddress, InternalGroupAddress)
         ) or not self.has_group_address(telegram.destination_address):
             return False
         if not isinstance(
@@ -166,21 +190,18 @@ class RemoteValue(ABC, Generic[DPTPayloadType, ValueType]):
                 device_name=self.device_name,
                 feature_name=self.feature_name,
             )
+        decoded_payload = self.from_knx(_new_payload)
         self.xknx.state_updater.update_received(self)
-        if self.payload is None or always_callback or self.payload != _new_payload:
-            self.payload = _new_payload
+        if self._value is None or always_callback or self._value != decoded_payload:
+            self._value = decoded_payload
+            self.telegram = telegram
             if self.after_update_cb is not None:
                 await self.after_update_cb()
         return True
 
-    @property
-    def value(self) -> Optional[ValueType]:
-        """Return current value."""
-        if self.payload is None:
-            return None
-        return self.from_knx(self.payload)
-
-    async def _send(self, payload: DPTPayloadType, response: bool = False) -> None:
+    async def _send(
+        self, payload: DPTArray | DPTBinary, response: bool = False
+    ) -> None:
         """Send payload as telegram to KNX bus."""
         if self.group_address is not None:
             telegram = Telegram(
@@ -212,14 +233,15 @@ class RemoteValue(ABC, Generic[DPTPayloadType, ValueType]):
             )
             return
 
-        payload = self.to_knx(value)  # pylint: disable=assignment-from-no-return
+        payload = self.to_knx(value)
         await self._send(payload, response)
-        # self.payload is set and after_update_cb() called when the outgoing telegram is processed.
+        # self._value is set and after_update_cb() called when the outgoing telegram is processed.
 
     async def respond(self) -> None:
         """Send current payload as GroupValueResponse telegram to KNX bus."""
-        if self.payload is not None:
-            await self._send(self.payload, response=True)
+        if self._value is not None:
+            payload = self.to_knx(self._value)
+            await self._send(payload, response=True)
 
     async def read_state(self, wait_for_result: bool = False) -> None:
         """Send GroupValueRead telegram for state address to KNX bus."""
@@ -245,22 +267,22 @@ class RemoteValue(ABC, Generic[DPTPayloadType, ValueType]):
                 await value_reader.send_group_read()
 
     @property
-    def unit_of_measurement(self) -> Optional[str]:
+    def unit_of_measurement(self) -> str | None:
         """Return the unit of measurement."""
         return None
 
     def group_addr_str(self) -> str:
         """Return object as readable string."""
-        return "{}/{}/{}/{}".format(
-            self.group_address.__repr__(),
-            self.group_address_state.__repr__(),
-            self.payload,
-            self.value,
+        return "<{}, {}, {}, {} />".format(
+            self.group_address,
+            self.group_address_state,
+            list(map(str, self.passive_group_addresses)),
+            self.value.__repr__(),
         )
 
     def __str__(self) -> str:
         """Return object as string representation."""
-        return '<{} device_name="{}" feature_name="{}" {}/>'.format(
+        return '<{} device_name="{}" feature_name="{}" {} />'.format(
             self.__class__.__name__,
             self.device_name,
             self.feature_name,
